<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>IsometricGridLeft</name>
    <message>
        <location filename="../IsometricGridLeft.js" line="+35"/>
        <source>&amp;Left Projection</source>
        <translation>&amp;Levé promítání</translation>
    </message>
</context>
</TS>
